RawConfig

Trait RawConfig 

pub trait RawConfig {
    type Ctx;
}
The RawConfig trait defines a basic interface for all configurations used within the framework for neural networks, their layers, and more.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors