Parameters for constructing neural network models. This module implements parameters using the ParamsBase struct and its associated types. The ParamsBase struct provides:
The associated types follow suite with the ndarray crate, each of which defines a
different style of representation for the parameters.
Modules
Structs
- Params
Base - this structure extends the
ArrayBasetype to include bias
Enums
Type Aliases
- ArcParams
- a type alias for shared parameters
- CowParams
- a type alias for borrowed parameters
- Params
- a type alias for owned parameters
- Params
View - a type alias for an immutable view of the parameters
- Params
View Mut - a type alias for a mutable view of the parameters
- RawMut
Params - a mutable raw view of the parameters; internally uses a mutable pointer
- RawView
Params - a raw view of the parameters; internally uses a constant pointer