pub trait ApplyOnce<Rhs> {
type Output;
// Required method
fn apply_once(self, rhs: Rhs) -> Self::Output;
}Expand description
The ApplyOnce trait consumes the container and applies the given function to every
element before returning a new container with the results.
Required Associated Types
Required Methods
fn apply_once(self, rhs: Rhs) -> Self::Output
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".