Clip

Trait Clip 

pub trait Clip<T> {
    type Output;

    // Required method
    fn clip(&self, min: T, max: T) -> Self::Output;
}
A trait denoting objects capable of being clipped between some minimum and some maximum.

Required Associated Types

type Output

the type output produced by the operation

Required Methods

fn clip(&self, min: T, max: T) -> Self::Output

limits the values within an object to a range between min and max

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A, S, D> Clip<A> for ArrayBase<S, D, A>
where A: 'static + Clone + PartialOrd, S: Data<Elem = A>, D: Dimension,

Source

type Output = ArrayBase<OwnedRepr<A>, D>

Source

fn clip(&self, min: A, max: A) -> <ArrayBase<S, D, A> as Clip<A>>::Output

Implementors