ClipMut

Trait ClipMut 

pub trait ClipMut<T = f32> {
    // Required methods
    fn clip_between(&mut self, min: T, max: T);
    fn clip_inf_nan(&mut self, on_inf: T, on_nan: T);
    fn clip_inf_nan_between(&mut self, boundary: T, on_inf: T, on_nan: T);
    fn clip_inf(&mut self, threshold: T);
    fn clip_max(&mut self, threshold: T);
    fn clip_min(&mut self, threshold: T);
    fn clip_norm_l1(&mut self, threshold: T);
    fn clip_norm_l2(&mut self, threshold: T);
    fn clip_nan(&mut self, threshold: T);
}
This trait enables tensor clipping; it is implemented for ArrayBase

Required Methods

fn clip_between(&mut self, min: T, max: T)

clip the tensor between the minimum and maximum values

fn clip_inf_nan(&mut self, on_inf: T, on_nan: T)

fn clip_inf_nan_between(&mut self, boundary: T, on_inf: T, on_nan: T)

clip the tensor between a boundary value, replacing any infinite or NaN values

fn clip_inf(&mut self, threshold: T)

clip any infinite values in the tensor

fn clip_max(&mut self, threshold: T)

clip the tensor to a maximum threshold

fn clip_min(&mut self, threshold: T)

clip the tensor to a minimum threshold

fn clip_norm_l1(&mut self, threshold: T)

this method normalizes the tensor then clips any values outside of the given threshold. the tensor is normalized using the L1 norm

fn clip_norm_l2(&mut self, threshold: T)

this method normalizes the tensor then clips any values outside of the given threshold. the tensor is normalized using the L2 norm

fn clip_nan(&mut self, threshold: T)

clip any NaN values in the tensor

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A, S, D> ClipMut<A> for ArrayBase<S, D, A>
where A: 'static + Clone + Float, S: DataMut<Elem = A>, D: Dimension,

Source

fn clip_between(&mut self, min: A, max: A)

Source

fn clip_inf_nan(&mut self, on_inf: A, on_nan: A)

Source

fn clip_inf_nan_between(&mut self, boundary: A, on_inf: A, on_nan: A)

Source

fn clip_inf(&mut self, threshold: A)

Source

fn clip_max(&mut self, threshold: A)

Source

fn clip_min(&mut self, threshold: A)

Source

fn clip_nan(&mut self, threshold: A)

Source

fn clip_norm_l1(&mut self, threshold: A)

Source

fn clip_norm_l2(&mut self, threshold: A)

Implementors