pub trait Decrement {
type Output;
// Required method
fn dec(self) -> Self::Output;
}Expand description
Decrement is a chainable trait that defines a decrement method,
effectively removing a single unit from the original object to create another
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".