pub trait IntoAxis { // Required method fn into_axis(self) -> Axis; }
The IntoAxis trait is used to define a conversion routine that takes a type and wraps it in an Axis type.
IntoAxis
Axis
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".