Inverse

Trait Inverse 

pub trait Inverse {
    type Output;

    // Required method
    fn inverse(&self) -> Self::Output;
}
The Inverse trait generically establishes an interface for computing the inverse of a type, regardless of if its a tensor, scalar, or some other compatible type.

Required Associated Types

type Output

the output, or result, of the inverse operation

Required Methods

fn inverse(&self) -> Self::Output

compute the inverse of the current object, producing some Output

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> Inverse for ArrayBase<OwnedRepr<T>, Dim<[usize; 2]>>

Implementors