pub trait LayoutExt:
RawModelLayout
+ RawModelLayoutMut
+ Clone
+ Debug { }Expand description
The LayoutExt trait defines an interface for object capable of representing the
layout; i.e. the number of input, hidden, and output features of a neural network model
containing some number of hidden layers.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".