pub trait MaskFill<A, D>where
D: Dimension,{
type Output;
// Required method
fn masked_fill(
&self,
mask: &ArrayBase<OwnedRepr<bool>, D>,
value: A,
) -> Self::Output;
}Expand description
This trait is used to fill an array with a value based on a mask. The mask is a boolean array of the same shape as the array.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".