pub trait PercentChange<Rhs = Self> {
type Output;
// Required method
fn percent_change(self, rhs: Rhs) -> Self::Output;
}Expand description
The PercentChange trait establishes a binary operator for computing the percent change
between two values where the caller is considered the original value.
Required Associated Types
Required Methods
fn percent_change(self, rhs: Rhs) -> Self::Output
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".