pub trait PredictWithConfidence<Rhs>: Predict<Rhs> {
type Confidence;
// Required method
fn predict_with_confidence(
&self,
input: &Rhs,
) -> Option<(Self::Output, Self::Confidence)>;
}Expand description
The PredictWithConfidence trait is an extension of the Predict trait, providing
an additional method to obtain predictions along with a confidence score.
Required Associated Types
type Confidence
Required Methods
fn predict_with_confidence( &self, input: &Rhs, ) -> Option<(Self::Output, Self::Confidence)>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".