ScalarTensorData

Trait ScalarTensorData 

pub trait ScalarTensorData: RawTensorData<Elem = Self> { }
A marker trait used to denote tensors that represent scalar values; more specifically, we consider any type implementing the RawTensorData type where the Elem associated type is the implementor itself a scalar value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> ScalarTensorData for T
where T: RawTensorData<Elem = T>,