StoreEntry

Trait StoreEntry 

pub trait StoreEntry<'a, K, V> {
    // Required methods
    fn is_occupied(&self) -> bool;
    fn is_vacant(&self) -> bool;
}
The StoreEntry trait establishes a common interface for all entries within a key-value store. These types enable in-place manipulation of key-value pairs by allowing for keys to point to empty or vacant slots within the store.

Required Methods

fn is_occupied(&self) -> bool

checks if the entry is occupied

fn is_vacant(&self) -> bool

checks if the entry is vacant

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, K, V> StoreEntry<'a, K, V> for Entry<'a, K, V>

Source

impl<K, V, S> StoreEntry<'_, K, V> for Entry<'_, K, V, S>

Source

impl<K, V> StoreEntry<'_, K, V> for Entry<'_, K, V>

Implementors